#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINMOD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINMOD_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/minmod.hpp>

#endif
